%iGEM_TUeindhoven_2012_total_script

clear all;
close all;
set(gcf,'PaperUnits','centimeters');
set(gcf,'PaperSize',[12 9]);
set(gcf,'PaperPosition',[0 0 12 9]);
set(0,'defaultaxesfontsize',18);

Ca_ex = 1; %Extracellular calcium concentration (uM)

%Parameters of CaM
kmf = 8.3; %Forward rate constant (uM-3 s-1)
kmb = 100^(1/60); %Backward rate constant (s-1)
CaMtot = 25; %Total calmodulin (bound + unbound)

%Parameters of CaN
knf = 8.3e-2; %Forward rate constant (uM-1 s-1)
knb = 5^(1/60); %Backward rate constant (s-1)
CaNtot = 25; %total calcineurin (bound + unbound), dimensionless

%Parameters of total nuclear fraction Crz1
khf = 0.4^(1/60); %nuclear import rate constant (s-1)
khb = 0.1^(1/60); %nuclear export rate constant (s-1)
nsites = 13; %number of relevant regulatory phosporylation sites
lzero = 10^(-nsites/2); %basic equilibrium constant
lamda = 5; %increment factor

%Parameters Michaelis Menten
kx = 500; %binding constant Transporter X (uM)
k1 = 4.3; %binding constant Pmc1 (uM)
k2 = 0.1; %binding constant Pmr1 (uM)
k3 = 100; %binding constant Vcx1 (uM)
vx = 16.7; %rate parameter of Transporter X (uM s-1)
v1 = 500; %rate parameter of Pmc1 (uM s-1)
v2 = 1.67; %rate parameter of Pmr1 (uM s-1)
v3 = 167; %rate parameter of Vcx1 (uM s-1)
kc = 10; %feedback control constant
alpha = 0.006^(1/60); %growth rate constant (s-1)

%Parameters of ionic current flow
i = 1; %Integral power of hypothetical activation variable
j = 1; %Integral power of hypothetical inactivation variable
g = 0.116; %Membrane conductance (microS (microSiemens))
K = 0.01e3; %Halfway inactivation concentration (uM)
Vn = 30e-15; %Volume of the cell (l)

%Parameters Geco kinetics
nhill = 2.6; %number of binding calcium
kgf = 8.17e15; %forward rate constant
kgb = 0.675; %backward rate constant
Gectot = 25; %total GECO (bound + unbound)

%Initial Conditions:
x0 = [10^-8 10^-8 10 10^-8 25 0.41];
%x0[1]: initial concentration calcium-calmodulin combination (uM)
%x0[2]: initial concentration calcium-calcineurin combination (uM)
%x0[3]: initial concentration calcium-GECO combination (uM)
%x0[4]: initial concentration Crz1 (uM)
%x0[5]: initial concentration cystolic calcium (uM)
%x0[6]: Hypothetical activation variable (mV)

%Parameter vector
par = [i, j, g, K, Vn, Ca_ex, kmf, kmb, CaMtot, knf, knb, CaNtot, khf, ...
    khb, nsites, lzero, lamda, kx, k1, k2, k3, vx, v1, v2, v3, kc, alpha, ...
    nhill, kgf, kgb, Gectot];
%Addressing the parameters

%Integrate ODEs:
tspan = [0:0.01:20]; %Time span (s)
odeoptions = odeset('RelTol',1e-4,'AbsTol',1e-6,'NonNegative', [1 1 1 1 1]); %Tolerances
[t,x] = ode15s(@iGEM_TUeindhoven_2012_total_ode,tspan,x0,odeoptions,par);

%Plot results:
h=figure('position',[100 0 1100 1100],'paperpositionmode','auto','color','none','InvertHardcopy','off');
hold on;
title('Results of ODE','FontSize',22)
axis([0 20 0 30]);
xlabel('Time [s]')
ylabel('Concentration [microMolair]')
hl1 = line(t,x(:,1),'Color','r','LineWidth',2);
hl2 = line(t,x(:,2),'Color','y','LineWidth',2);
hl3 = line(t,x(:,3),'Color','m','LineWidth',2);
hl4 = line(t,x(:,4),'Color','g','LineWidth',2);
hl5 = line(t,x(:,5),'Color','b','LineWidth',2);
legend([hl1 hl2 hl3 hl4 hl5],{'[CaM]' '[CaN]' '[CaGECO]' '[Crz]' '[Ca]'});
print -deps epsFig
hold off;
